
shader = love.graphics.newShader([[
  
  
  #define MAX_LIGHTS 16 //Maxiumum of 16 lights
  
  extern Image normalMap;
  
  uniform vec3 lights[MAX_LIGHTS]; 
  uniform float lightIntensities[MAX_LIGHTS];
  uniform vec3 lightColours[MAX_LIGHTS];
  
  vec4 effect( vec4 color, Image texture, vec2 texture_coords, vec2 screen_coords )
  {
    vec4 pixel = Texel(texture, texture_coords); //This is the current pixel color
    vec3 pixel3 = vec3(pixel.r, pixel.g, pixel.b);
    vec4 normalPixel = Texel(normalMap, texture_coords);
    vec3 normal = vec3(normalPixel.r, normalPixel.g, normalPixel.b);
    normal = (normal-0.5)*2;
    
    //Now iterate through lights
    
    vec3 reflectedColour = vec3(0);
    
    
    for (int i = 0; i < MAX_LIGHTS; i++)
    {
      
      float lightIntensity = lightIntensities[i];
      
      if (lightIntensity == 0) break; // If the light intensity is 0, assume that you reached the end of the array
      
      
      vec3 light          = lights[i];
      vec3 lightColour    = lightColours[i];
      
      
      vec3 distance = light - vec3(screen_coords.x, screen_coords.y, 0);
      
      float lightFalloff = 1/pow(length(distance), 2);
      vec3 lightDirection = normalize(distance);
      
      float dotProduct = max((dot(lightDirection, normal))+0.1, 0);
      
      reflectedColour += dotProduct*pixel3*lightColour*lightFalloff*lightIntensity*10000;
      
    }
    
    
   
    
    return min(vec4(pixel3 + reflectedColour*0.5, pixel.a), 1);
  }
  
  ]])
  